@@ -98,7 +98,7 @@ def write_map(filename,m,nest=False,dtype=np.float32,fits_IDL=True,coord=None,co
       They will be considered as I, Q, U maps. 
       Supports masked maps, see the `ma` function.
     nest : bool, optional
-      If False, ordering scheme is NESTED, otherwise, it is RING. Default: RING.
+      If True, ordering scheme is assumed to be NESTED, otherwise, RING. Default: RING.
       The map ordering is not modified by this function, the input map array
       should already be in the desired ordering (run `ud_grade` beforehand).
     fits_IDL : bool, optional
@@ -193,8 +193,6 @@ def read_map(filename,field=0,dtype=np.float64,nest=False,hdu=1,h=False,
       If True, return also the header. Default: False.
     verbose : bool, optional
       If True, print a number of diagnostic messages
-    as_ma : bool, optional
-      If True, return also the header. Default: False.
     memmap : bool, optional
       Argument passed to pyfits.open, if True, the map is not read into memory,
       but only the required pixels are read when needed. Default: False.
