@@ -46,7 +46,7 @@ template<Healpix_Ordering_Scheme scheme>static void
   intp is1=steps[0],is2=steps[1],is3=steps[2], os=steps[3];
   char *ip1=args[0], *ip2=args[1], *ip3=args[2], *op=args[3];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(intp i=0; i<n; i++, ip1+=is1, ip2+=is2, ip3+=is3, op+=os)
@@ -54,8 +54,12 @@ template<Healpix_Ordering_Scheme scheme>static void
       long nside = *(long*)ip1;
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, scheme); }
-      *(long *)op = hb.ang2pix(pointing(*(double *)ip2,*(double *)ip3));
-    }
+      try {
+        *(long *)op = hb.ang2pix(pointing(*(double *)ip2,*(double *)ip3));
+      } catch(PlanckError &e) {
+        *(long *)op = -1;
+      }
+  }
 }
 
 /*
@@ -68,7 +72,7 @@ template<Healpix_Ordering_Scheme scheme> static void
   register intp is1=steps[0],is2=steps[1],os1=steps[2],os2=steps[3];
   char *ip1=args[0], *ip2=args[1], *op1=args[2], *op2=args[3];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2, op1+=os1, op2+=os2)
@@ -76,9 +80,14 @@ template<Healpix_Ordering_Scheme scheme> static void
       long nside = *(long*)ip1;
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, scheme); }
-      pointing ptg = hb.pix2ang(*(long *)ip2);
-      *(double *)op1 = ptg.theta;
-      *(double *)op2 = ptg.phi;
+      try {
+        pointing ptg = hb.pix2ang(*(long *)ip2);
+        *(double *)op1 = ptg.theta;
+        *(double *)op2 = ptg.phi;
+      } catch (PlanckError & e) {
+        *(double *)op1 = NAN;
+        *(double *)op2 = NAN;
+      }
     }
 }
 
@@ -92,7 +101,7 @@ ufunc_ring2nest(char **args, intp *dimensions, intp *steps, void *func)
   register intp is1=steps[0],is2=steps[1],os=steps[2];
   char *ip1=args[0], *ip2=args[1], *op=args[2];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2, op+=os)
@@ -100,7 +109,11 @@ ufunc_ring2nest(char **args, intp *dimensions, intp *steps, void *func)
       long nside = *(long*)ip1;
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, RING); }
-      *(long *)op = hb.ring2nest(*(long *)ip2);
+      try {
+        *(long *)op = hb.ring2nest(*(long *)ip2);
+      } catch(PlanckError & e) {
+        *(long *)op = -1;
+      }
     }
 }
 
@@ -114,7 +127,7 @@ static void
   register intp is1=steps[0],is2=steps[1],os=steps[2];
   char *ip1=args[0], *ip2=args[1], *op=args[2];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2, op+=os)
@@ -122,7 +135,11 @@ static void
       long nside = *(long*)ip1;
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, NEST); }
-      *(long *)op = hb.nest2ring(*(long *)ip2);
+      try {
+        *(long *)op = hb.nest2ring(*(long *)ip2);
+      } catch(PlanckError & e) {
+        *(long *)op = -1;
+      }
     }
 }
 
@@ -137,7 +154,7 @@ template<Healpix_Ordering_Scheme scheme> static void
   register intp is1=steps[0],is2=steps[1],os1=steps[2],os2=steps[3],os3=steps[4];
   char *ip1=args[0], *ip2=args[1], *op1=args[2], *op2=args[3], *op3=args[4];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2, op1+=os1, op2+=os2, op3+=os3)
@@ -145,10 +162,16 @@ template<Healpix_Ordering_Scheme scheme> static void
       long nside = *(long*)ip1;
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, scheme); }
-      vec3 v = hb.pix2vec(*(long *)ip2);
-      *(double *)op1 = v.x;
-      *(double *)op2 = v.y;
-      *(double *)op3 = v.z;
+      try {
+        vec3 v = hb.pix2vec(*(long *)ip2);
+        *(double *)op1 = v.x;
+        *(double *)op2 = v.y;
+        *(double *)op3 = v.z;
+      } catch (PlanckError & e) {
+        *(double *)op1 = NAN;
+        *(double *)op2 = NAN;
+        *(double *)op3 = NAN;
+      }
     }
 }
 
@@ -162,7 +185,7 @@ template<Healpix_Ordering_Scheme scheme> static void
   register intp is1=steps[0],is2=steps[1],is3=steps[2],is4=steps[3],os1=steps[4];
   char *ip1=args[0], *ip2=args[1], *ip3=args[2], *ip4=args[3], *op1=args[4];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2, ip3+=is3, ip4+=is4, op1+=os1)
@@ -171,8 +194,12 @@ template<Healpix_Ordering_Scheme scheme> static void
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, scheme); }
       vec3 v (*(double *)ip2,*(double *)ip3,*(double *)ip4);
-      long ipix = hb.vec2pix(v);
-      *(long *)op1 = ipix;
+      try {
+        long ipix = hb.vec2pix(v);
+        *(long *)op1 = ipix;
+      } catch (PlanckError &e) {
+        *(long *)op1 = -1;
+      }
     }
 }
 
@@ -191,27 +218,38 @@ template<Healpix_Ordering_Scheme scheme> static void
     *op1=args[3],*op2=args[4],*op3=args[5],*op4=args[6],
     *op5=args[7],*op6=args[8],*op7=args[9],*op8=args[10];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   long oldnside=-1;
 
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2, ip3+=is3,
         op1+=os1,op2+=os2,op3+=os3,op4+=os4,
         op5+=os5,op6+=os6,op7+=os7,op8+=os8 )
     {
-      fix_arr<int,4> pix;
+      fix_arr<int64,4> pix;
       fix_arr<double,4> wgt;
       long nside = *(long*)ip1;
       if (nside!=oldnside)
         { oldnside=nside; hb.SetNside(nside, scheme); }
-      hb.get_interpol(pointing(*(double*)ip2, *(double*)ip3), pix, wgt);
-      *(long*)op1 = (long)pix[0];
-      *(long*)op2 = (long)pix[1];
-      *(long*)op3 = (long)pix[2];
-      *(long*)op4 = (long)pix[3];
-      *(double*)op5 = wgt[0];
-      *(double*)op6 = wgt[1];
-      *(double*)op7 = wgt[2];
-      *(double*)op8 = wgt[3];
+      try {
+        hb.get_interpol(pointing(*(double*)ip2, *(double*)ip3), pix, wgt);
+        *(long*)op1 = (long)pix[0];
+        *(long*)op2 = (long)pix[1];
+        *(long*)op3 = (long)pix[2];
+        *(long*)op4 = (long)pix[3];
+        *(double*)op5 = wgt[0];
+        *(double*)op6 = wgt[1];
+        *(double*)op7 = wgt[2];
+        *(double*)op8 = wgt[3];
+      } catch (PlanckError &e) {
+        *(long*)op1 = -1;
+        *(long*)op2 = -1;
+        *(long*)op3 = -1;
+        *(long*)op4 = -1;
+        *(double*)op5 = NAN;
+        *(double*)op6 = NAN;
+        *(double*)op7 = NAN;
+        *(double*)op8 = NAN;
+      }
     }
 }
 
@@ -230,25 +268,62 @@ template<Healpix_Ordering_Scheme scheme> static void
     *op1=args[2],*op2=args[3],*op3=args[4],*op4=args[5],
     *op5=args[6],*op6=args[7],*op7=args[8],*op8=args[9];
 
-  Healpix_Base hb;
+  Healpix_Base2 hb;
   for(i=0; i<n; i++, ip1+=is1, ip2+=is2,
         op1+=os1,op2+=os2,op3+=os3,op4+=os4,
         op5+=os5,op6+=os6,op7+=os7,op8+=os8 )
     {
-      fix_arr<int,8> pix;
+      fix_arr<int64,8> pix;
       hb.SetNside(*(long*)ip1, scheme);
-      hb.neighbors(*(long*)ip2, pix);
-      *(long*)op1 = (long)pix[0];
-      *(long*)op2 = (long)pix[1];
-      *(long*)op3 = (long)pix[2];
-      *(long*)op4 = (long)pix[3];
-      *(long*)op5 = (long)pix[4];
-      *(long*)op6 = (long)pix[5];
-      *(long*)op7 = (long)pix[6];
-      *(long*)op8 = (long)pix[7];
+      try {
+        hb.neighbors(*(long*)ip2, pix);
+        *(long*)op1 = (long)pix[0];
+        *(long*)op2 = (long)pix[1];
+        *(long*)op3 = (long)pix[2];
+        *(long*)op4 = (long)pix[3];
+        *(long*)op5 = (long)pix[4];
+        *(long*)op6 = (long)pix[5];
+        *(long*)op7 = (long)pix[6];
+        *(long*)op8 = (long)pix[7];
+      } catch (PlanckError & e) {
+        *(long*)op1 = -1;
+        *(long*)op2 = -1;
+        *(long*)op3 = -1;
+        *(long*)op4 = -1;
+        *(long*)op5 = -1;
+        *(long*)op6 = -1;
+        *(long*)op7 = -1;
+        *(long*)op8 = -1;
+      }
     }
 }
 
+/*
+  max_pixrad
+*/
+static void
+  ufunc_max_pixrad(char **args, intp *dimensions, intp *steps, void *func)
+{
+  register intp i, n=dimensions[0];
+  register intp is1=steps[0],os1=steps[1];
+  char *ip1=args[0], *op1=args[1];
+
+  Healpix_Base2 hb;
+  long oldnside=-1;
+
+  for(i=0; i<n; i++, ip1+=is1, op1+=os1)
+    {
+      long nside = *(long*)ip1;
+      if (nside!=oldnside)
+        { oldnside=nside; hb.SetNside(nside, NEST);
+        	/* ring and nest should give the same result */ 
+        }
+      double max_pixrad = hb.max_pixrad();
+      *(double *)op1 = max_pixrad;
+    }
+}
+
+
 static char *docstring = CP_(
   "This module contains basic ufunc related to healpix pixelisation\n"
   "scheme, such as ang2pix, ring<->nest swapping, etc.\n"
@@ -300,6 +375,9 @@ static PyUFuncGenericFunction get_neighbors_ring_functions[] = {
 static PyUFuncGenericFunction get_neighbors_nest_functions[] = {
   ufunc_get_neighbors<NEST>
 };
+static PyUFuncGenericFunction max_pixrad_functions[] = {
+  ufunc_max_pixrad
+};
 
 
 static void * blank_data[] = { (void *)NULL };
@@ -334,6 +412,9 @@ static char get_neighbors_nest_signatures[] = {
   PyArray_LONG, PyArray_LONG, PyArray_LONG, PyArray_LONG, // output
   PyArray_LONG, PyArray_LONG, PyArray_LONG, PyArray_LONG // output
 };
+static char max_pixrad_signatures[] = {
+  PyArray_LONG, PyArray_DOUBLE  
+};
 
 PyMODINIT_FUNC
 init_healpy_pixel_lib(void)
@@ -463,6 +544,15 @@ init_healpy_pixel_lib(void)
   PyDict_SetItemString(d, "_get_neighbors_nest", f);
   Py_DECREF(f);
 
+
+  f = PyUFunc_FromFuncAndData(max_pixrad_functions, blank_data,
+                              max_pixrad_signatures, 1,
+                              1, 1, PyUFunc_None, CP_("max_pixrad"),
+                              CP_("nside -> max_distance to pixel corners from center)"),0);
+  PyDict_SetItemString(d, "_max_pixrad", f);
+  Py_DECREF(f);
+
+
   f = PyFloat_FromDouble(Healpix_undef);
 
   PyDict_SetItemString(d, "UNSEEN", f);
