@@ -23,6 +23,9 @@ class TestNoCrash(unittest.TestCase):
     def test_gnomview_nocrash(self):
         gnomview(self.m)
 
+    def test_orthview_nocrash(self):
+        orthview(self.m)
+
     def test_mollzoom_nocrash(self):
         mollzoom(self.m)
 
@@ -35,5 +38,8 @@ class TestNoCrash(unittest.TestCase):
     def test_gnomview_ma_nocrash(self):
         gnomview(self.ma)
 
+    def test_orthview_ma_nocrash(self):
+        orthview(self.ma)
+
     def test_mollzoom_ma_nocrash(self):
         mollzoom(self.ma)
